==> haskell-x509-1.7.7-25-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-x509.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 x509
version:              1.7.7
visibility:           public
id:                   x509-1.7.7-LhMN4kw7sKBHSJ4lHoUydE
key:                  x509-1.7.7-LhMN4kw7sKBHSJ4lHoUydE
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             http://github.com/vincenthz/hs-certificate
synopsis:             X509 reader and writer
description:          X509 reader and writer. please see README
category:             Data
abi:                  ee2cbb50b51ec33e5bcbf6d34eac41e7
exposed:              True
exposed-modules:      Data.X509 Data.X509.EC
hidden-modules:
    Data.X509.Internal Data.X509.CertificateChain
    Data.X509.AlgorithmIdentifier Data.X509.DistinguishedName
    Data.X509.Cert Data.X509.PublicKey Data.X509.PrivateKey
    Data.X509.Ext Data.X509.ExtensionRaw Data.X509.CRL Data.X509.OID
    Data.X509.Signed

import-dirs:          /usr/lib/ghc-9.0.2/site-local/x509-1.7.7
library-dirs:         /usr/lib/ghc-9.0.2/site-local/x509-1.7.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-x509
hs-libraries:         HSx509-1.7.7-LhMN4kw7sKBHSJ4lHoUydE
depends:
    asn1-encoding-0.9.6-5dD37upqebN8D1gUuuDEvq
    asn1-parse-0.9.5-2zBt5AFZX2dHhd8oo7980D
    asn1-types-0.3.4-6umwx72d1Fxfloyfha7vd base-4.15.1.0
    bytestring-0.10.12.1 containers-0.6.4.1
    cryptonite-0.30-Aits1YrYIJo6ZxdO6tapoS
    hourglass-0.2.12-8Zib7FXQV7iJJeLOkzqwn1
    memory-0.17.0-3DbDQrj54CLAPAnWUJBJ4b
    pem-0.2.4-24PX2rj9TyTCtyHY8MTt8f transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-x509/html/x509.haddock
haddock-html:         /usr/share/doc/haskell-x509/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-x509-1.7.7-26-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-x509.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 x509
version:              1.7.7
visibility:           public
id:                   x509-1.7.7-7S2H2TYPxoRAwwqjUcRaiT
key:                  x509-1.7.7-7S2H2TYPxoRAwwqjUcRaiT
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             http://github.com/vincenthz/hs-certificate
synopsis:             X509 reader and writer
description:          X509 reader and writer. please see README
category:             Data
abi:                  4908def2e279aa441a06558768000438
exposed:              True
exposed-modules:      Data.X509 Data.X509.EC
hidden-modules:
    Data.X509.Internal Data.X509.CertificateChain
    Data.X509.AlgorithmIdentifier Data.X509.DistinguishedName
    Data.X509.Cert Data.X509.PublicKey Data.X509.PrivateKey
    Data.X509.Ext Data.X509.ExtensionRaw Data.X509.CRL Data.X509.OID
    Data.X509.Signed

import-dirs:          /usr/lib/ghc-9.0.2/site-local/x509-1.7.7
library-dirs:         /usr/lib/ghc-9.0.2/site-local/x509-1.7.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-x509
hs-libraries:         HSx509-1.7.7-7S2H2TYPxoRAwwqjUcRaiT
depends:
    asn1-encoding-0.9.6-HCqlXoBMrzbG6QMC7SXNXt
    asn1-parse-0.9.5-COZuE0Yh1GXG4uDtTXTmnZ
    asn1-types-0.3.4-F31TVoYwDAfE8xXxAO9GLY base-4.15.1.0
    bytestring-0.10.12.1 containers-0.6.4.1
    cryptonite-0.30-EulWVZvKrH8KexMmvSPppe
    hourglass-0.2.12-DOZNkSPxrlnE9i2jrA0vdJ
    memory-0.17.0-3DbDQrj54CLAPAnWUJBJ4b
    pem-0.2.4-JdUN6kkRWa8DKIvhp3yyre transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-x509/html/x509.haddock
haddock-html:         /usr/share/doc/haskell-x509/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
